@@ -1,8 +1,14 @@
+import logging
 from git import Repo
 from chibi.file import Chibi_path
 from chibi_command import Command
 
+
+logger = logging.getLogger( 'chibi_command.git' )
+
+
 class Git:
+    @classmethod
     def clone( cls, url, dest=None ):
         """
         clona el repositorio de la url
@@ -32,3 +38,12 @@ class Git:
         if src is None:
             src = Chibi_path.current_dir()
         Repo( src ).remote().pull()
+
+    @classmethod
+    def checkout( cls, branch, src=None ):
+        if src is None:
+            src = Chibi_path.current_dir()
+        repo = Repo( src )
+        current_branch = repo.active_branch
+        logger.info( f"cambiando '{current_branch.name}' a '{branch}'" )
+        repo.git.checkout( branch )
