@@ -1,10 +1,28 @@
-from chibi_command import Command
+from chibi.atlas import Chibi_atlas
+from chibi_command import Command, Command_result
 from chibi_hybrid.chibi_hybrid import Chibi_hybrid
 
 
+class Info_result( Command_result ):
+    def parse_result( self ):
+        result = Chibi_atlas()
+        for l in self.result.split( '\n' ):
+            l = l.strip()
+            if not l:
+                continue
+            k, v = l.split( ':' )
+            v = v.strip()
+            result[k.lower()] = v.lower()
+        self.result = result
+
+    @property
+    def is_running( self ):
+        return self.result.state == 'running'
+
+
 class Create( Command ):
     command = 'lxc-create'
-    captive = False;
+    captive = False
 
     @Chibi_hybrid
     def name( cls, name ):
@@ -27,7 +45,7 @@ class Create( Command ):
 
 class Start( Command ):
     command = 'lxc-start'
-    captive = False;
+    captive = False
 
     @Chibi_hybrid
     def name( cls, name ):
@@ -50,7 +68,7 @@ class Start( Command ):
 
 class Attach( Command ):
     command = 'lxc-attach'
-    captive = False;
+    captive = False
 
     @Chibi_hybrid
     def name( cls, name ):
@@ -64,3 +82,19 @@ class Attach( Command ):
     def build_tuple( self, *args, **kw ):
         return (
             self.command, *self.build_kw( **kw ), *self.args, '--', *args )
+
+
+class Info( Command ):
+    command = 'lxc-info'
+    captive = True
+    args = ( '-H', )
+    result_class = Info_result
+
+    @Chibi_hybrid
+    def name( cls, name ):
+        return cls( '-n', name )
+
+    @name.instancemethod
+    def name( self, name ):
+        self.add_args( '-n', name )
+        return self
